Piculet
=======

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   extract
   preprocess
   api
   authors
   history


Indices and Tables
==================

* :ref:`genindex`
* :ref:`search`
